@@ -1,18 +1,17 @@
 """Eve Universe models"""
 
 import urllib
+from enum import Enum
 
 from django.db import models
 from django.utils import translation
 from django.utils.timezone import now
 from django.utils.translation import gettext
 
-from allianceauth.eveonline.models import EveCorporationInfo
 from allianceauth.services.hooks import get_extension_logger
 from app_utils.logging import LoggerAddTag
 
 from .. import __title__
-from ..constants import EveCategoryId, EveGroupId, EveTypeId
 from ..managers import EveSovereigntyMapManager, EveUniverseManager
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
@@ -20,6 +19,27 @@ logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 NAMES_MAX_LENGTH = 255
 
 
+class EveSpaceType(str, Enum):
+    UNKNOWN = "unknown"
+    HIGHSEC = "highsec"
+    LOWSEC = "lowsec"
+    NULLSEC = "nullsec"
+    W_SPACE = "w-space"
+
+    @classmethod
+    def from_solar_system(cls, eve_solar_system: "EveSolarSystem") -> "EveSpaceType":
+        """returns the space type"""
+        if eve_solar_system.is_null_sec:
+            return cls.NULLSEC
+        elif eve_solar_system.is_low_sec:
+            return cls.LOWSEC
+        elif eve_solar_system.is_high_sec:
+            return cls.HIGHSEC
+        elif eve_solar_system.is_w_space:
+            return cls.W_SPACE
+        return cls.UNKNOWN
+
+
 class EsiNameLocalization(models.Model):
     """Base class for adding localization support for name field"""
 
@@ -291,14 +311,6 @@ class EveUniverse(EsiNameLocalization, models.Model):
 class EveCategory(EveUniverse):
     """category in Eve Online"""
 
-    @property
-    def is_starbase(self):
-        return self.id == EveCategoryId.STARBASE
-
-    @property
-    def is_upwell_structure(self):
-        return self.id == EveCategoryId.STRUCTURE
-
     class EveUniverseMeta:
         esi_pk = "category_id"
         esi_method = "get_universe_categories_category_id"
@@ -324,11 +336,6 @@ class EveGroup(EveUniverse):
 class EveType(EveUniverse):
     """type in Eve Online"""
 
-    # starbase sizes
-    STARBASE_SMALL = 1
-    STARBASE_MEDIUM = 2
-    STARBASE_LARGE = 3
-
     EVE_IMAGESERVER_BASE_URL = "https://images.evetech.net"
     URL_PROFILE_TYPE = "https://www.kalkoken.org/apps/eveitems/"
 
@@ -340,57 +347,6 @@ class EveType(EveUniverse):
         esi_pk = "type_id"
         esi_method = "get_universe_types_type_id"
 
-    @property
-    def is_poco(self):
-        return self.id == EveTypeId.CUSTOMS_OFFICE
-
-    @property
-    def is_starbase(self):
-        return self.eve_group_id == EveGroupId.CONTROL_TOWER
-
-    @property
-    def is_upwell_structure(self):
-        try:
-            return self.eve_group.eve_category_id == EveCategoryId.STRUCTURE
-        except AttributeError:
-            logger.warning(
-                'Group "%s" does not have a category. This is a data error. '
-                "Please update your local SDE data",
-                self.eve_group,
-            )
-            return False
-
-    @property
-    def is_fuel_block(self):
-        return self.eve_group_id == EveGroupId.FUEL_BLOCK
-
-    @property
-    def starbase_size(self):
-        """return the size of a starbase or None if this type is not a starbase"""
-        if not self.is_starbase:
-            return None
-        elif "medium" in self.name.lower():
-            return self.STARBASE_MEDIUM
-        elif "small" in self.name.lower():
-            return self.STARBASE_SMALL
-        else:
-            return self.STARBASE_LARGE
-
-    @property
-    def starbase_fuel_per_hour(self):
-        """returns the number of fuel blocks consumed per hour
-        or None if not a starbase
-        """
-        size = self.starbase_size
-        if size == self.STARBASE_LARGE:
-            return 40
-        elif size == self.STARBASE_MEDIUM:
-            return 20
-        elif size == self.STARBASE_SMALL:
-            return 10
-        else:
-            return None
-
     @property
     def profile_url(self) -> str:
         return f"{self.URL_PROFILE_TYPE}?typeId={self.id}"
@@ -434,12 +390,6 @@ class EveConstellation(EveUniverse):
 class EveSolarSystem(EveUniverse):
     """solar system in Eve Online"""
 
-    TYPE_HIGHSEC = "highsec"
-    TYPE_LOWSEC = "lowsec"
-    TYPE_NULLSEC = "nullsec"
-    TYPE_W_SPACE = "w-space"
-    TYPE_UNKNOWN = "unknown"
-
     eve_constellation = models.ForeignKey(
         EveConstellation, on_delete=models.CASCADE, related_name="eve_solar_systems"
     )
@@ -470,46 +420,6 @@ class EveSolarSystem(EveUniverse):
         """returns True if this solar system is in wormhole space, else False"""
         return 31000000 <= self.id < 32000000
 
-    @property
-    def space_type(self):
-        """returns the space type"""
-        if self.is_null_sec:
-            return self.TYPE_NULLSEC
-        elif self.is_low_sec:
-            return self.TYPE_LOWSEC
-        elif self.is_high_sec:
-            return self.TYPE_HIGHSEC
-        elif self.is_w_space:
-            return self.TYPE_W_SPACE
-        else:
-            return self.TYPE_UNKNOWN
-
-    @property
-    def sov_alliance_id(self) -> int:
-        """returns ID of sov owning alliance for this system or None"""
-        if self.is_null_sec:
-            try:
-                sov_map = EveSovereigntyMap.objects.get(solar_system_id=self.id)
-                alliance_id = sov_map.alliance_id if sov_map.alliance_id else None
-            except EveSovereigntyMap.DoesNotExist:
-                alliance_id = None
-        else:
-            alliance_id = None
-
-        return alliance_id
-
-    def corporation_has_sov(self, corporation: EveCorporationInfo) -> bool:
-        """returns true if given corporation has sov in this solar system
-        else False
-        """
-        if not self.is_null_sec:
-            return None
-        else:
-            alliance_id = (
-                int(corporation.alliance.alliance_id) if corporation.alliance else None
-            )
-            return alliance_id and (self.sov_alliance_id == alliance_id)
-
 
 class EvePlanet(EveUniverse):
     """planet in Eve Online"""
