@@ -41,9 +41,17 @@ from ..app_settings import (
     STRUCTURES_STRUCTURE_SYNC_GRACE_MINUTES,
 )
 from ..constants import EveGroupId, EveTypeId
+from ..core import starbases
 from ..helpers.esi_fetch import _esi_client, esi_fetch, esi_fetch_with_localization
 from ..managers import OwnerManager
-from .eveuniverse import EveMoon, EvePlanet, EveSolarSystem, EveType, EveUniverse
+from .eveuniverse import (
+    EveMoon,
+    EvePlanet,
+    EveSolarSystem,
+    EveSovereigntyMap,
+    EveType,
+    EveUniverse,
+)
 from .notifications import EveEntity, Notification, NotificationType, Webhook
 from .structures import PocoDetails, Structure, StructureItem
 
@@ -172,7 +180,8 @@ class Owner(models.Model):
         Group,
         default=None,
         blank=True,
-        help_text="Groups to be pinged for each notification - ",
+        related_name="+",
+        help_text="Groups to be pinged for each notification. ",
     )
     structures_last_update_at = models.DateTimeField(
         null=True,
@@ -184,7 +193,8 @@ class Owner(models.Model):
         "Webhook",
         default=None,
         blank=True,
-        help_text="notifications are sent to these webhooks. ",
+        related_name="owners",
+        help_text="Notifications are sent to these webhooks. ",
     )
 
     objects = OwnerManager()
@@ -915,20 +925,21 @@ class Owner(models.Model):
         if "fuels" in starbase_details:
             for fuel in starbase_details["fuels"]:
                 fuel_type, _ = EveType.objects.get_or_create_esi(fuel["type_id"])
-                if fuel_type.is_fuel_block:
+                if starbases.is_fuel_block(fuel_type):
                     fuel_quantity = fuel["quantity"]
         if fuel_quantity:
             starbase_type, _ = EveType.objects.get_or_create_esi(starbase["type_id"])
             solar_system, _ = EveSolarSystem.objects.get_or_create_esi(
                 starbase["system_id"]
             )
-            sov_discount = (
-                0.25 if solar_system.corporation_has_sov(self.corporation) else 0
+            has_sov = EveSovereigntyMap.objects.corporation_has_sov(
+                eve_solar_system=solar_system, corporation=self.corporation
             )
+            sov_discount = 0.25 if has_sov else 0
             seconds = math.floor(
                 3600
                 * fuel_quantity
-                / (starbase_type.starbase_fuel_per_hour * (1 - sov_discount))
+                / (starbases.starbase_fuel_per_hour(starbase_type) * (1 - sov_discount))
             )
             last_modified = parsedate_to_datetime(
                 response.headers.get("Last-Modified", format_datetime(now()))
@@ -1009,7 +1020,7 @@ class Owner(models.Model):
             f.write("\n")
 
     def _store_notifications(self, notifications: list) -> int:
-        """stores new notifications in database.
+        """Store new notifications in database.
         Returns number of newly created objects.
         """
         # identify new notifications
@@ -1021,8 +1032,7 @@ class Owner(models.Model):
             for obj in notifications
             if obj["notification_id"] not in existing_notification_ids
         ]
-        # create new notif objects
-        new_notification_objects = list()
+        # create new notification objects
         for notification in new_notifications:
             sender_type = EveEntity.Category.from_esi_name(notification["sender_type"])
             if sender_type != EveEntity.Category.OTHER:
@@ -1036,24 +1046,21 @@ class Owner(models.Model):
                 )
             text = notification["text"] if "text" in notification else None
             is_read = notification["is_read"] if "is_read" in notification else None
-            new_notification_objects.append(
-                Notification(
-                    notification_id=notification["notification_id"],
-                    owner=self,
-                    sender=sender,
-                    timestamp=notification["timestamp"],
-                    # at least one type has a trailing white space
-                    # which we need to remove
-                    notif_type=notification["type"].strip(),
-                    text=text,
-                    is_read=is_read,
-                    last_updated=now(),
-                    created=now(),
-                )
+            # at least one type has a trailing white space
+            # which we need to remove
+            notif_type = notification["type"].strip()
+            Notification.objects.create(
+                notification_id=notification["notification_id"],
+                owner=self,
+                sender=sender,
+                timestamp=notification["timestamp"],
+                notif_type=notif_type,
+                text=text,
+                is_read=is_read,
+                last_updated=now(),
+                created=now(),
             )
-
-        Notification.objects.bulk_create(new_notification_objects)
-        return len(new_notification_objects)
+        return len(new_notifications)
 
     def _process_timers_for_notifications(self, token: Token):
         """processes notifications for timers if any"""
@@ -1098,7 +1105,7 @@ class Owner(models.Model):
             )
             structure_id_2_moon_id = dict()
             for notification in notifications:
-                parsed_text = notification.get_parsed_text()
+                parsed_text = notification.parsed_text()
                 moon_id = parsed_text["moonID"]
                 structure_id = parsed_text["structureID"]
                 structure_id_2_moon_id[structure_id] = moon_id
@@ -1154,7 +1161,6 @@ class Owner(models.Model):
             "result": _("completed successfully"),
             "message_details": message_details,
         }
-
         notify(
             user,
             title=_("%(title)s: %(topic)s updated for " "%(owner)s: %(result)s")
@@ -1261,7 +1267,7 @@ class OwnerCharacter(models.Model):
     """Character for syncing owner data with ESI."""
 
     owner = models.ForeignKey(
-        "Owner", on_delete=models.CASCADE, related_name="characters"
+        Owner, on_delete=models.CASCADE, related_name="characters"
     )
     character_ownership = models.ForeignKey(
         CharacterOwnership,
