@@ -17,6 +17,7 @@ from .models import (
     FuelAlertConfig,
     JumpFuelAlertConfig,
     Notification,
+    NotificationType,
     Owner,
     Webhook,
 )
@@ -35,8 +36,8 @@ def update_all_structures():
     """
     if not fetch_esi_status().is_ok:
         logger.warning("ESI currently not available. Aborting.")
-    else:
-        chain(update_sov_map.si(), update_structures.si()).delay()
+        return
+    chain(update_sov_map.si(), update_structures.si()).delay()
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
@@ -117,15 +118,52 @@ def fetch_all_notifications():
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
-def process_notifications_for_owner(owner_pk, user_pk=None):
+def process_notifications_for_owner(owner_pk: int, user_pk: int = None):
     """Fetch all notification for owner from ESI and processes them."""
     if not fetch_esi_status().is_ok:
         logger.warning("ESI currently not available. Aborting.")
-    else:
-        owner = Owner.objects.get(pk=owner_pk)
-        owner.fetch_notifications_esi(_get_user(user_pk))
-        owner.send_new_notifications()
-        send_queued_messages_for_webhooks(owner.webhooks.filter(is_active=True))
+        return
+    chain(
+        fetch_notification_for_owner.si(owner_pk=owner_pk, user_pk=user_pk),
+        update_existing_notifications.si(owner_pk=owner_pk),
+        send_new_notifications_for_owner.si(owner_pk=owner_pk),
+    ).apply_async(priority=TASK_PRIO_HIGH)
+
+
+@shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
+def fetch_notification_for_owner(owner_pk: int, user_pk: int = None):
+    """Fetch notifications from ESI."""
+    owner = Owner.objects.get(pk=owner_pk)
+    owner.fetch_notifications_esi(_get_user(user_pk))
+
+
+@shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
+def update_existing_notifications(owner_pk: int):
+    """Update structure relation for existing notifications if needed."""
+    owner = Owner.objects.get(pk=owner_pk)
+    notif_need_update_qs = owner.notifications.filter(
+        notif_type__in=NotificationType.structure_related, structures__isnull=True
+    )
+    notif_need_update_count = notif_need_update_qs.count()
+    if notif_need_update_count > 0:
+        updated_count = 0
+        for notif in notif_need_update_qs:
+            if notif.update_related_structures():
+                updated_count += 1
+        logger.info(
+            "%s: Updated structure relation for %d of %d relevant notifications",
+            owner,
+            updated_count,
+            notif_need_update_count,
+        )
+
+
+@shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
+def send_new_notifications_for_owner(owner_pk: int):
+    """Send new notifications to Discord."""
+    owner = Owner.objects.get(pk=owner_pk)
+    owner.send_new_notifications()
+    send_queued_messages_for_webhooks(owner.webhooks.filter(is_active=True))
 
 
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
@@ -143,12 +181,16 @@ def send_jump_fuel_notifications_for_config(config_pk: int):
 @shared_task(time_limit=STRUCTURES_TASKS_TIME_LIMIT)
 def send_notifications(notification_pks: list) -> None:
     """Send notifications defined by list of pks (used for admin action)."""
-    notifications = Notification.objects.filter(pk__in=notification_pks)
-    if notifications:
-        logger.info("Trying to send %s notifications to webhooks...", notification_pks)
-        for notif in notifications:
-            notif.send_to_configured_webhooks()
+    notifications_qs = Notification.objects.filter(pk__in=notification_pks)
+    notifs_sent = 0
+    if notifications_qs.exists():
+        for notif in notifications_qs:
+            if notif.send_to_configured_webhooks():
+                notifs_sent += 1
         send_queued_messages_for_webhooks(Webhook.objects.filter(is_active=True))
+    logger.info(
+        "Sent %d of %d notifications to webhooks", notifs_sent, len(notification_pks)
+    )
 
 
 def send_queued_messages_for_webhooks(webhooks: Iterable[Webhook]):
